@@ -159,24 +159,29 @@ ml_lda.spark_connection <- function(x, formula = NULL, k = 10, max_iter = 20, do
 
   jobj <- invoke_new(x, "org.apache.spark.ml.clustering.LDA", uid) %>% (
     function(obj) {
-      do.call(invoke,
-              c(obj, "%>%", Filter(function(x) !is.null(x),
-                              list(
-                                   list("setK", .args[["k"]]),
-                                   list("setMaxIter", .args[["max_iter"]]),
-                                   list("setSubsamplingRate", .args[["subsampling_rate"]]),
-                                   list("setOptimizer", .args[["optimizer"]]),
-                                   list("setCheckpointInterval", .args[["checkpoint_interval"]]),
-                                   jobj_set_param_helper(obj, "setKeepLastCheckpoint", .args[["keep_last_checkpoint"]], "2.0.0", TRUE),
-                                   list("setLearningDecay", .args[["learning_decay"]]),
-                                   list("setLearningOffset", .args[["learning_offset"]]),
-                                   list("setOptimizeDocConcentration", .args[["optimize_doc_concentration"]]),
-                                   list("setFeaturesCol", .args[["features_col"]]),
-                                   list("setTopicDistributionCol", .args[["topic_distribution_col"]]),
-                                   jobj_set_param_helper(obj, "setDocConcentration", .args[["doc_concentration"]]),
-                                   jobj_set_param_helper(obj, "setTopicConcentration", .args[["topic_concentration"]]),
-                                   jobj_set_param_helper(obj, "setSeed", .args[["seed"]])))))
-  })
+      do.call(
+        invoke,
+        c(obj, "%>%", Filter(
+          function(x) !is.null(x),
+          list(
+            list("setK", .args[["k"]]),
+            list("setMaxIter", .args[["max_iter"]]),
+            list("setSubsamplingRate", .args[["subsampling_rate"]]),
+            list("setOptimizer", .args[["optimizer"]]),
+            list("setCheckpointInterval", .args[["checkpoint_interval"]]),
+            jobj_set_param_helper(obj, "setKeepLastCheckpoint", .args[["keep_last_checkpoint"]], "2.0.0", TRUE),
+            list("setLearningDecay", .args[["learning_decay"]]),
+            list("setLearningOffset", .args[["learning_offset"]]),
+            list("setOptimizeDocConcentration", .args[["optimize_doc_concentration"]]),
+            list("setFeaturesCol", .args[["features_col"]]),
+            list("setTopicDistributionCol", .args[["topic_distribution_col"]]),
+            jobj_set_param_helper(obj, "setDocConcentration", .args[["doc_concentration"]]),
+            jobj_set_param_helper(obj, "setTopicConcentration", .args[["topic_concentration"]]),
+            jobj_set_param_helper(obj, "setSeed", .args[["seed"]])
+          )
+        ))
+      )
+    })
 
   new_ml_lda(jobj)
 }
