@@ -6,8 +6,10 @@ make_approx_nearest_neighbors <- function(jobj) {
     num_nearest_neighbors <- cast_scalar_integer(num_nearest_neighbors)
     dist_col <- cast_string(dist_col)
     jobj %>%
-      invoke("approxNearestNeighbors",
-             dataset, key, num_nearest_neighbors, dist_col) %>%
+      invoke(
+        "approxNearestNeighbors",
+        dataset, key, num_nearest_neighbors, dist_col
+      ) %>%
       sdf_register()
   }
 }
@@ -20,8 +22,10 @@ make_approx_similarity_join <- function(jobj) {
     threshold <- cast_scalar_double(threshold)
     dist_col <- cast_string(dist_col)
     jobj %>%
-      invoke("approxSimilarityJoin",
-             dataset_a, dataset_b, threshold, dist_col) %>%
+      invoke(
+        "approxSimilarityJoin",
+        dataset_a, dataset_b, threshold, dist_col
+      ) %>%
       invoke("select", list(
         spark_sql_column(sc, "datasetA.id", "id_a"),
         spark_sql_column(sc, "datasetB.id", "id_b"),
@@ -42,8 +46,7 @@ make_approx_similarity_join <- function(jobj) {
 #' @param dist_col Output column for storing the distance between each result row and the key.
 #' @export
 ml_approx_nearest_neighbors <- function(
-  model, dataset, key, num_nearest_neighbors, dist_col = "distCol"
-) {
+                                        model, dataset, key, num_nearest_neighbors, dist_col = "distCol") {
   model$approx_nearest_neighbors(dataset, key, num_nearest_neighbors, dist_col)
 }
 
@@ -53,7 +56,6 @@ ml_approx_nearest_neighbors <- function(
 #' @param threshold The threshold for the distance of row pairs.
 #' @export
 ml_approx_similarity_join <- function(
-  model, dataset_a, dataset_b, threshold, dist_col = "distCol"
-) {
+                                      model, dataset_a, dataset_b, threshold, dist_col = "distCol") {
   model$approx_similarity_join(dataset_a, dataset_b, threshold, dist_col)
 }
