@@ -33,14 +33,16 @@ ft_one_hot_encoder.spark_connection <- function(x, input_cols = NULL, output_col
   ) %>%
     c(rlang::dots_list(...)) %>%
     validator_ml_one_hot_encoder()
-  if(is_required_spark(x, "3.0.0")) {
+  if (is_required_spark(x, "3.0.0")) {
     estimator <- spark_pipeline_stage(
       x, "org.apache.spark.ml.feature.OneHotEncoder",
       input_cols = .args[["input_cols"]], output_cols = .args[["output_cols"]], uid = .args[["uid"]]
     ) %>%
-      invoke("%>%",
-             list("setHandleInvalid", .args[["handle_invalid"]]),
-             list("setDropLast", .args[["drop_last"]])) %>%
+      invoke(
+        "%>%",
+        list("setHandleInvalid", .args[["handle_invalid"]]),
+        list("setDropLast", .args[["drop_last"]])
+      ) %>%
       new_ml_one_hot_encoder()
   } else {
     if (length(.args[["input_cols"]]) > 1 || length(.args[["output_cols"]]) > 1) {
@@ -62,7 +64,7 @@ ft_one_hot_encoder.spark_connection <- function(x, input_cols = NULL, output_col
 #' @export
 ft_one_hot_encoder.ml_pipeline <- function(x, input_cols = NULL, output_cols = NULL, handle_invalid = "error",
                                            drop_last = TRUE, uid = random_string("one_hot_encoder_"), ...) {
-  if(is_required_spark(spark_connection(x), "3.0.0")) {
+  if (is_required_spark(spark_connection(x), "3.0.0")) {
     stage <- ft_one_hot_encoder.spark_connection(
       x = spark_connection(x),
       input_cols = input_cols,
@@ -89,7 +91,7 @@ ft_one_hot_encoder.ml_pipeline <- function(x, input_cols = NULL, output_cols = N
 #' @export
 ft_one_hot_encoder.tbl_spark <- function(x, input_cols = NULL, output_cols = NULL, handle_invalid = "error",
                                          drop_last = TRUE, uid = random_string("one_hot_encoder_"), ...) {
-  if(is_required_spark(spark_connection(x), "3.0.0")) {
+  if (is_required_spark(spark_connection(x), "3.0.0")) {
     stage <- ft_one_hot_encoder.spark_connection(
       x = spark_connection(x),
       input_cols = input_cols,
